==> common-1.3.0.8-sources.jar: cn/gtmap/gtc/workflow/domain/define/StartSettingDto.java <==
package cn.gtmap.gtc.workflow.domain.define;

/**
 * @author zhouk
 * @Title: StartSettingDto
 * @ProjectName workflow
 * @Description:启动配置
 * @date 2019/1/2917:02
 */
public class StartSettingDto {

    private String  id;                     //主键

    private String name;                    //名称

    private Integer processDeadLine;        //流程办理期限(天数)

    private Integer priorityUser;           //是否优先人员计算（1：true，0：false）

    private String workdaySettingId;          //工作日设置

    private String workdaySettingName;       //工作日设置名称

    private String customUrl;               //自定义url

    private String callBack;                //子页面的回调函数

    private Integer startOver;              //是否直接启动 0：false 1：true

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getProcessDeadLine() {
        return processDeadLine;
    }

    public void setProcessDeadLine(Integer processDeadLine) {
        this.processDeadLine = processDeadLine;
    }

    public Integer getPriorityUser() {
        return priorityUser;
    }

    public void setPriorityUser(Integer priorityUser) {
        this.priorityUser = priorityUser;
    }

    public String getWorkdaySettingId() {
        return workdaySettingId;
    }

    public void setWorkdaySettingId(String workdaySettingId) {
        this.workdaySettingId = workdaySettingId;
    }

    public String getWorkdaySettingName() {
        return workdaySettingName;
    }

    public void setWorkdaySettingName(String workdaySettingName) {
        this.workdaySettingName = workdaySettingName;
    }

    public String getCustomUrl() {
        return customUrl;
    }

    public void setCustomUrl(String customUrl) {
        this.customUrl = customUrl;
    }

    public Integer getStartOver() {
        return startOver;
    }

    public void setStartOver(Integer startOver) {
        this.startOver = startOver;
    }

    public String getCallBack() {
        return callBack;
    }

    public void setCallBack(String callBack) {
        this.callBack = callBack;
    }
}

==> common-1.3.0.95-sources.jar: cn/gtmap/gtc/workflow/domain/define/StartSettingDto.java <==
package cn.gtmap.gtc.workflow.domain.define;

/**
 * @author zhouk
 * @Title: StartSettingDto
 * @ProjectName workflow
 * @Description:启动配置
 * @date 2019/1/2917:02
 */
public class StartSettingDto {

    private String  id;                     //主键

    private String name;                    //名称

    private Double processDeadLine;        //流程办理期限(天数)

    private Integer priorityUser;           //是否优先人员计算（1：true，0：false）

    private String workdaySettingId;          //工作日设置

    private String workdaySettingName;       //工作日设置名称

    private String customUrl;               //自定义url

    private String callBack;                //子页面的回调函数

    private Integer startOver;              //是否直接启动 0：false 1：true

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }


    public Double getProcessDeadLine() {
        return processDeadLine;
    }

    public void setProcessDeadLine(Double processDeadLine) {
        this.processDeadLine = processDeadLine;
    }

    public Integer getPriorityUser() {
        return priorityUser;
    }

    public void setPriorityUser(Integer priorityUser) {
        this.priorityUser = priorityUser;
    }

    public String getWorkdaySettingId() {
        return workdaySettingId;
    }

    public void setWorkdaySettingId(String workdaySettingId) {
        this.workdaySettingId = workdaySettingId;
    }

    public String getWorkdaySettingName() {
        return workdaySettingName;
    }

    public void setWorkdaySettingName(String workdaySettingName) {
        this.workdaySettingName = workdaySettingName;
    }

    public String getCustomUrl() {
        return customUrl;
    }

    public void setCustomUrl(String customUrl) {
        this.customUrl = customUrl;
    }

    public Integer getStartOver() {
        return startOver;
    }

    public void setStartOver(Integer startOver) {
        this.startOver = startOver;
    }

    public String getCallBack() {
        return callBack;
    }

    public void setCallBack(String callBack) {
        this.callBack = callBack;
    }
}
